@@ -569,6 +569,25 @@ class InfluxUtil:
         cls._init(conf)
         return list(cls.CONN.query(sql, epoch='ms').get_points())
 
+    @classmethod
+    def write(cls, conf: dict, tbl: str, sql_res: list, time_precision='ms'):
+        """向influxdb写入数据
+        :sql_res 格式：sql查询出来的原始格式
+        """
+        cls._init(conf)
+        json_data_list = []
+        for data in sql_res:
+            json_data = {
+                'measurement': tbl,
+                'time': data.pop('time'),
+                'tags': {
+                    'tid': data.pop('tid')
+                },
+                'fields': data,
+            }
+            json_data_list.append(json_data)
+        cls.CONN.write_points(json_data_list, time_precision=time_precision)
+
     @classmethod
     def write_data(cls, conf: dict, tbl: str, data_list: list):
         """向influxdb写入数据
